@@ -4,9 +4,9 @@
 
 ;; Author: Fabrice Niessen <(concat "fniessen" at-sign "pirilampo.org")>
 ;; URL: https://github.com/fniessen/emacs-leuven-theme
-;; Package-Version: 2.6.213
-;; Package-Revision: c3546e6a84c1
-;; Last-Updated: 2025-12-23 17:47
+;; Package-Version: 20250917.1957
+;; Package-Revision: 802f5593b83c
+;; Last-Updated: 2025-04-22 11:31
 ;; Keywords: color theme
 
 ;; This file is part of GNU Emacs.
@@ -749,8 +749,6 @@ more...")
    `(magit-diff-del ((,class ,diff-removed)))
    `(magit-diff-file-header ((,class (:height 1.1 :weight bold :foreground "#4183C4"))))
    `(magit-diff-hunk-header ((,class ,diff-hunk-header)))
-   `(magit-diff-hunk-heading ((,class (:foreground "grey20" :background "grey80"))))
-   `(magit-diff-hunk-heading-highlight ((,class ,diff-header)))
    `(magit-diff-none ((,class ,diff-none)))
    `(magit-header ((,class (:foreground "white" :background "#FF4040"))))
    `(magit-item-highlight ((,class (:background "#EAF2F5"))))
